"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getBinanceTickerStream = void 0;
var operators_1 = require("rxjs/operators");
var public_ws_handler_1 = require("../ws_clients/public_ws_handler");
var getBinanceTickerStream = function (baseAsset, quoteAsset) {
    var pair = ("" + baseAsset + quoteAsset).toLowerCase();
    var streamName = pair + "@miniTicker";
    return public_ws_handler_1.getBinancePublicObservableFromWS([streamName]).pipe(operators_1.map(function (_a) {
        var _b = _a.data, 
        /* https://docs.binance.org/api-reference/dex-api/ws-streams.html#8-individual-symbol-ticker-streams
        
            // e: stream_name,
            E: ticker_time,
            // s: pair,
            // p: price_change,
            // P: price_change_percent,
            // w: weighted_avg_price,
            // x: first_trade_price,
            c: last_price,
            // Q: last_quantity,
            // b: best_bid_price,
            // B: best_bid_quantity,
            // a: best_ask_price,
            // A: best_ask_quantity,
            o: open_price,
            h: high_price,
            l: low_price,
            v: total_traded_base_asset_volume,
            q: total_traded_quote_asset_volume,
        */
        utcTimestamp = _b.E, price = _b.c;
        return ({
            exchange: 'binance',
            utcTimestamp: utcTimestamp,
            pair: pair,
            price: price,
        });
    }));
};
exports.getBinanceTickerStream = getBinanceTickerStream;
